==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/ToolActionNumberInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionNumberInputDescription } from "./ToolActionNumberInputDescription";
/**
 * @hidden
 */
export let ToolActionNumberInputDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionNumberInputDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionNumberInputDescriptionMetadata.a == null) {
                ToolActionNumberInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionNumberInputDescriptionMetadata.c(ToolActionNumberInputDescriptionMetadata.a);
            }
            if (a.g(ToolActionNumberInputDescriptionMetadata.a)) {
                return;
            }
            a.s(ToolActionNumberInputDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionNumberInputDescriptionMetadata.b(a);
            a.u("ToolActionNumberInput", () => new ToolActionNumberInputDescription());
            a.t("ToolActionNumberInput", ToolActionNumberInputDescriptionMetadata.a);
        }
    }
    ToolActionNumberInputDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionNumberInputDescriptionMetadata, 'ToolActionNumberInputDescriptionMetadata');
    ToolActionNumberInputDescriptionMetadata.a = null;
    return ToolActionNumberInputDescriptionMetadata;
})();

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ToolActionNumberInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionNumberInputDescription } from "./ToolActionNumberInputDescription";
/**
 * @hidden
 */
export let ToolActionNumberInputDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionNumberInputDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionNumberInputDescriptionMetadata.a == null) {
                ToolActionNumberInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionNumberInputDescriptionMetadata.c(ToolActionNumberInputDescriptionMetadata.a);
            }
            if (a.j(ToolActionNumberInputDescriptionMetadata.a)) {
                return;
            }
            a.y(ToolActionNumberInputDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionNumberInputDescriptionMetadata.b(a);
            a.aa("ToolActionNumberInput", () => new ToolActionNumberInputDescription());
            a.z("ToolActionNumberInput", ToolActionNumberInputDescriptionMetadata.a);
        }
    }
    ToolActionNumberInputDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionNumberInputDescriptionMetadata, 'ToolActionNumberInputDescriptionMetadata');
    ToolActionNumberInputDescriptionMetadata.a = null;
    return ToolActionNumberInputDescriptionMetadata;
})();
